@@ -27,15 +27,11 @@
 #include <kprogress.h>
 
 #include <qmap.h>
-#include <qstringlist.h>
+#include <qlabel.h>
 
 #include "digikam_mainwindow.h"
-
-
-extern "C" {
-	#include <gphoto2.h>
-}
-
+#include "gphoto_interface.h"
+#include "camera_folder.h"
 
 /** Digikam is the base class of the project */
 class Digikam : public Digikam_MainWindow
@@ -49,50 +45,40 @@ class Digikam : public Digikam_MainWindow
     ~Digikam();
 
 
-    protected slots:
+  protected slots:
 
-      void slot_connectToCamera();
-      void slot_selectAll();
-      void slot_downloadImages();
-      //void slot_help();
+      void slot_connect();
       void slot_setup();
+      void slot_downloadImages();
+      void slot_deleteImages();
+      void slot_folderViewClicked(QListViewItem *);
+      void slot_setSelection(int);
+      void slot_browse(); 
       void slot_close();
-      void slot_browse();
+      void slot_setStatusMsg(const QString&);
+      void slot_about();
+      
+      //void slot_help(); 
+
 
 
  private:
 
-    static QMap<Camera *, Digikam *> my_cameraMap;
-    static void debug_func (GPLogLevel level, const char *domain, const char *format,
-			    va_list args, void *data);
-    static void status_func (Camera *camera, const char *status, void *data);
-    static void message_func (Camera *camera, const char *message, void *data);
-    static void progress_func (Camera *camera, float percentage, void *data);
-
     void initGlobals();
+    void initView();
     int  initCamera();
-    void getFolderNames(QString folder);
-    void getThumbNails();
-    void updateThumbNails();
-
-    Camera *my_camera;
-    QString my_cameraModel;
-    QString my_cameraPort;
-    QString my_cameraPortPath;
-    QString my_cameraFolder;
-    QStringList my_cameraFolderList;
-    int my_cameraNumFolders;
-
-    QString globTempDir;
-
+    int getFolderNames(Camera_Folder* camFolder);
+    int getIcons();
     void setStatusMsg(const QString &);
-    void setStatusTempMsg(const QString &);
-    void setProgressValue(int progress);
+    void setAbilitiesButtons();
 
+    Gphoto_Interface *gpInterface;
     KStatusBar *statusBar;
     KProgress  *progressBar;
 
-    bool my_cameraInitialised;
+    QString my_cameraFolder; 
+    QLabel* statusLabel;
+
 
 };
 
